[openssh-commits] [openssh] 01/01: Allow low-priv tests to write to pipe dir.
git+noreply at mindrot.org
git+noreply at mindrot.org
Thu Jul 18 10:19:56 AEST 2019
This is an automated email from the git hooks/post-receive script.
dtucker pushed a commit to branch master
in repository openssh.
commit d1c491ecb939ee10b341fa7bb6205dff19d297e5
Author: Darren Tucker <dtucker at dtucker.net>
Date: Thu Jul 18 10:17:54 2019 +1000
Allow low-priv tests to write to pipe dir.
When running regression tests with Valgrind and SUDO, the low-priv agent
tests need to be able to create pipes in the appropriate directory.
---
regress/test-exec.sh | 6 ++++--
1 file changed, 4 insertions(+), 2 deletions(-)
diff --git a/regress/test-exec.sh b/regress/test-exec.sh
index 27447076..a0bff311 100644
--- a/regress/test-exec.sh
+++ b/regress/test-exec.sh
@@ -154,8 +154,10 @@ SCP_BIN=${SCP}
if [ "x$USE_VALGRIND" != "x" ]; then
rm -rf $OBJ/valgrind-out $OBJ/valgrind-vgdb
mkdir -p $OBJ/valgrind-out $OBJ/valgrind-vgdb
- # ensure agent low-priv tests can write logs.
- chmod 777 $OBJ/valgrind-out
+ # When using sudo ensure low-priv tests can write pipes and logs.
+ if [ "x$SUDO" != "x" ]; then
+ chmod 777 $OBJ/valgrind-out $OBJ/valgrind-vgdb
+ fi
VG_TEST=`basename $SCRIPT .sh`
# Some tests are difficult to fix.
--
To stop receiving notification emails like this one, please contact
djm at mindrot.org.
More information about the openssh-commits
mailing list